==> flutter_widgetz-4.9.4.tar.gz: lib/src/time_field.dart <==
part of flutter_widgetz;

/// {@template flutter_widgetz.TimeField}
/// Wraps a call to [showTimePicker] in
/// an [InputDecorator] and [InkWell].
/// {@endtemplate}
class TimeField extends StatefulWidget {
  /// {@macro flutter_widgetz.TimeField}
  const TimeField({
    super.key,
    required this.onChanged,
    this.displayStringForTime = _defaultStringForTime,
    this.errorText,
    this.hasError = false,
    this.labelText,
    this.prefixIcon = Icons.timelapse,
    this.value,
  });

  /// Called whenever the value changes.
  final ValueChanged<TimeOfDay> onChanged;

  /// The string that is displayed in the input.
  final String Function(TimeOfDay?) displayStringForTime;

  /// The text shown when there is an error.
  final String? errorText;

  /// Determines if a error should be shown.
  final bool hasError;

  /// Optional text that describes the input field.
  final String? labelText;

  /// An icon that appears before the editable part of the text field.
  final IconData prefixIcon;

  /// The value of this input.
  final TimeOfDay? value;

  static String _defaultStringForTime(TimeOfDay? time) {
    return time?.toString() ?? '';
  }

  @override
  State<TimeField> createState() => _TimeFieldState();
}

class _TimeFieldState extends State<TimeField> {
  late FocusNode _focusNode;
  TimeOfDay? _value;

  @override
  void initState() {
    super.initState();
    _focusNode = FocusNode();
    _value = widget.value;
  }

  @override
  void dispose() {
    _focusNode.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final ThemeData theme = Theme.of(context);

    return InkWell(
      focusNode: _focusNode,
      onFocusChange: _onFocusChange,
      onTap: () => _showTimePicker(context),
      child: InputDecorator(
        isFocused: _focusNode.hasFocus,
        decoration: InputDecoration(
          errorText: widget.hasError ? widget.errorText : null,
          labelText: widget.labelText,
          prefixIcon: Icon(widget.prefixIcon),
        ),
        child: Text(
          widget.displayStringForTime(_value),
          style: theme.textTheme.titleMedium,
        ),
      ),
    );
  }

  void _showTimePicker(BuildContext context) {
    showTimePicker(
      context: context,
      initialTime: _value ?? TimeOfDay.now(),
    ).then(_onChange);
  }

  void _onChange(TimeOfDay? value) {
    _onFocusChange(true);
    if (value == null) {
      return;
    }
    setState(() {
      _value = value;
    });
    widget.onChanged(value);
  }

  void _onFocusChange(bool value) {
    if (value) {
      _focusNode.requestFocus();
    } else {
      _focusNode.unfocus();
    }
    setState(() {});
  }
}

==> flutter_widgetz-8.0.2.tar.gz: lib/src/time_field.dart <==
part of flutter_widgetz;

/// {@template flutter_widgetz.TimeField}
/// Wraps a call to [showTimePicker] in
/// an [InputDecorator] and [InkWell].
/// {@endtemplate}
class TimeField extends StatefulWidget {
  /// {@macro flutter_widgetz.TimeField}
  const TimeField({
    super.key,
    required this.onChanged,
    this.displayStringForTime = _defaultStringForTime,
    this.errorText,
    this.hasError = false,
    this.labelText,
    this.prefixIcon = const Icon(Icons.timelapse),
    this.value,
  });

  /// Called whenever the value changes.
  final ValueChanged<TimeOfDay> onChanged;

  /// The string that is displayed in the input.
  final String Function(TimeOfDay?) displayStringForTime;

  /// The text shown when there is an error.
  final String? errorText;

  /// Determines if a error should be shown.
  final bool hasError;

  /// Optional text that describes the input field.
  final String? labelText;

  /// An icon that appears before the editable part of the text field.
  final Widget prefixIcon;

  /// The value of this input.
  final TimeOfDay? value;

  static String _defaultStringForTime(TimeOfDay? time) {
    return time?.toString() ?? '';
  }

  @override
  State<TimeField> createState() => _TimeFieldState();
}

class _TimeFieldState extends State<TimeField> {
  late FocusNode _focusNode;
  TimeOfDay? _value;

  @override
  void initState() {
    super.initState();
    _focusNode = FocusNode();
    _value = widget.value;
  }

  @override
  void dispose() {
    _focusNode.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final ThemeData theme = Theme.of(context);

    return InkWell(
      focusNode: _focusNode,
      onFocusChange: _onFocusChange,
      onTap: () => _showTimePicker(context),
      child: InputDecorator(
        isFocused: _focusNode.hasFocus,
        decoration: InputDecoration(
          errorText: widget.hasError ? widget.errorText : null,
          labelText: widget.labelText,
          prefixIcon: widget.prefixIcon,
        ),
        child: Text(
          widget.displayStringForTime(_value),
          style: theme.textTheme.titleMedium,
        ),
      ),
    );
  }

  void _showTimePicker(BuildContext context) {
    showTimePicker(
      context: context,
      initialTime: _value ?? TimeOfDay.now(),
    ).then(_onChange);
  }

  void _onChange(TimeOfDay? value) {
    _onFocusChange(true);
    if (value == null) {
      return;
    }
    setState(() {
      _value = value;
    });
    widget.onChanged(value);
  }

  void _onFocusChange(bool value) {
    if (value) {
      _focusNode.requestFocus();
    } else {
      _focusNode.unfocus();
    }
    setState(() {});
  }
}
